import { Router } from '@angular/router';
import { Observable } from 'rxjs';
import { TreeNode } from '../../eo-framework/tree/tree.component';
import { Logger, BackendService, UserService, AppCacheService, Config, SystemService, DmsObject } from '@eo-sdk/core';
export declare class AgentService {
    private logger;
    private systemService;
    private backendService;
    private userService;
    private appCacheService;
    private config;
    private router;
    agentAvailability: {
        CONNECTED: string;
        AVAILABLE: string;
        UNAVAILABLE: string;
    };
    private pairingFailed;
    constructor(logger: Logger, systemService: SystemService, backendService: BackendService, userService: UserService, appCacheService: AppCacheService, config: Config, router: Router);
    /**
     * Adds a location entry to the agent services location history.
     * @param contextFolder The locations context folder
     * @param treeNode Node from the context folders structure tree
     */
    updateUserLocation(contextFolder: DmsObject, treeNode?: TreeNode): void;
    /**
     * Gets the agentToken. Will either get it from storage or generate a new one and persist it.
     */
    getAgentToken(forceNewToken?: any): Observable<string>;
    setAgentToken(token: any): Observable<boolean>;
    getAddConnectionLink(): Observable<string>;
    /**
     * Open a document via agent.
     *
     * @param document A document to open.
     * @param lock Boolean, if the dms item should be locked.
     */
    openDocument(document: any, lock: any): Observable<boolean>;
    /**
     * Download content via agent.
     * On completion, the agent will visualize the downloaded items.
     *
     * @param documents A document to open.
     */
    downloadContent(documents: any): Observable<boolean>;
    /**
     * Copy items to clipboard.
     *
     * @param documents List of documents with id, title, type and rendition.
     */
    copyToClipboard(documents: any): any;
    /**
     * Send items as email.
     *
     * @param documents List of documents with id, title, type and rendition.
     */
    sendAsMail(documents: any): any;
    /**
     * Checks if a paired agent is available.
     */
    hasPairedAgent(): Observable<boolean>;
    /**
     * Checks if an agent with the same user is available, which could be paired.
     *
     * @returns
     */
    couldPairAgent(): Observable<boolean>;
    /**
     * Tries to pair an agent.
     *
     * @returns
     */
    requestAgentPairing(): Observable<boolean>;
    sendExternalAction(executable: any, args: any): Observable<boolean>;
    sendMessage(message: any): Observable<boolean>;
}
