import { Observable } from 'rxjs';
import { TreeNode } from '../../eo-framework/tree/tree.component';
import { Router } from '@angular/router';
import { AgentService } from '../agent/agent.service';
import { AppCacheService, UploadRegistryService, DmsObject } from '@eo-sdk/core';
export interface EoLocation {
    id: string;
    type: string;
    title?: string;
    subFolder?: any;
}
/**
 * LocationService keeps track of the location a user visits inside enaio.
 * This service will be used by the AppAdd component for fetching objects allowed
 * to be added, because they may be restricted to a certain location.
 *
 * For components that display a location inside enaio use `LocationService.enter(id, type)`
 * in the components `OnInit` method and `LocationService.leave()` in its `OnDestroy` method.
 * See applications `ObjectStateComponent` for an example.
 */
export declare class LocationService {
    private appCache;
    private agentService;
    private uploadRegistry;
    private router;
    HISTORY_SIZE: number;
    private activeLocation;
    private locationSource;
    activeLocation$: Observable<any>;
    private locationHistory;
    private currentUploadTargets;
    constructor(appCache: AppCacheService, agentService: AgentService, uploadRegistry: UploadRegistryService, router: Router);
    /**
     * Enter a specific location. This will add the location to the local history
     * and set the active location.
     * @param dmsObject
     * @param treeNode Node from the context folders structure tree
     */
    enter(dmsObject: DmsObject, treeNode?: TreeNode): void;
    /**
     * Leave a location. This will remove the active location.
     */
    leave(): void;
    /**
     * Returns the location history
     * @return
     */
    getHistory(): EoLocation[];
    getActiveLocation(): EoLocation;
    /**
     * Adds a location entry to the history.
     * @param contextFolder The locations context folder
     * @param treeNode Node from the context folders structure tree
     */
    private addHistoryEntry(contextFolder, treeNode?);
    private isSameAsPrevious(contextFolder, treeNode?);
}
