import { Observable } from 'rxjs';
import { SearchFilter, SearchQuery, SearchState, SystemService, ObjectType, SearchService, EventService } from '@eo-sdk/core';
/**
 * AppSearchService is the apps main entry point for searching (used by the appBarSearch component).
 * It provides an `query$` observable components can subscribe to, to
 * stay in touch with updates to the query.
 */
export declare class AppSearchService {
    private searchService;
    private eventService;
    private system;
    private query;
    private lastQuery;
    private queryState;
    private querySource;
    private queryStateSource;
    query$: Observable<SearchQuery>;
    queryState$: Observable<SearchState>;
    objectTypeGroups: any[];
    constructor(searchService: SearchService, eventService: EventService, system: SystemService);
    private sortObjectTypeGroup(types);
    buildTypeGroupTree(): any[];
    /**
     * Override the current query by a different one.
     * This could be done by for example loading a stored query.
     *
     * @param query - the query that should replace the current query, this may be either a SearchQuery instance,
     * a JSON string of an object matching the search api
     */
    setQuery(query: SearchQuery): void;
    /**
     * Resets the current query.
     */
    clearQuery(): void;
    private isNewQuery(query);
    /**
     * toggles the searchmode from regular search to expert search and vice versa
     */
    toggleExpertMode(): void;
    setTerm(term: string): void;
    /**
     * Toggles a type filter.
     * @param type - object type
     */
    toggleQueryType(type: ObjectType): void;
    /**
     * Sets the queries target types.
     *
     * @param types - array of ObjectTypes
     * @param silent If set to true aggregate won't be called
     */
    setQueryTypes(types: ObjectType[], silent?: boolean): void;
    /**
     * Sets the queries target context type.
     *
     * @param type The context type to be set or null for resetting
     * @param silent If set to true aggregate won't be called
     */
    setContextType(type: ObjectType, silent?: boolean): void;
    private emitNewContextFolderType(type, silent?);
    /**
     * Toggles a created filter.
     * @param filter - the filter to be toggled
     */
    toggleQueryFilter(filter: SearchFilter, override?: boolean): void;
    /**
     * Adds a filter to the query.
     * @param filter - the filter to be added
     */
    addQueryFilter(filter: SearchFilter): void;
    /**
     * Removes a filter to the query.
     * @param filter - the filter to be removed
     */
    removeQueryFilter(filter: SearchFilter): void;
    /**
     * Sets the filters for an indexdata search.
     * Setting them will also remove all indexdata filters set before.
     *
     * @param filters - the filters to be set
     * @param silent If set to true aggregate won't be called
     */
    setIndexSearchQueryFilters(filters: SearchFilter[], silent?: boolean): void;
    getIndexSearchQueryFilters(query?: SearchQuery): SearchFilter[];
    /**
     * Determines whether or not the provided search filter belongs to a base param.
     *
     * @param filter - the filter to be checked
     */
    isBaseParamFilter(filter: SearchFilter): boolean;
    /**
     * Executes the current query as aggregate search
     */
    aggregate(baseParam?: string): void;
    /**
     * Reset the query
     */
    reset(silent?: boolean): void;
    exitIndexdataSearch(): void;
    /**
     * Executes the current query as aggregate search
     */
    getSearchState(query: SearchQuery): Observable<SearchState>;
    autocomplete(term: string): Observable<any>;
    /**
     * Finds the object type element inside of the queries target types
     * for a form elements name. Used e.g. for the search summary panel.
     *
     * @param formElementName - the name of the form element
     * @return the object type element matching the form elements name
     */
    getTargetTypeElementByName(formElementName: string): any;
}
