import { Observable } from 'rxjs';
import { ComponentFactoryResolver, InjectionToken, ViewContainerRef } from '@angular/core';
import { Router } from '@angular/router';
import { ActionListEntry } from '../interfaces/action-list-entry';
import { BpmService, DmsObject, CapabilitiesService } from '@eo-sdk/core';
export declare const ACTIONS: InjectionToken<any[]>;
export declare const CUSTOM_ACTIONS: InjectionToken<any[]>;
export interface ActionShowCommand {
    show: boolean;
    target?: string;
    selection: any[];
}
export declare class ActionService {
    private _componentFactoryResolver;
    private bpmService;
    private router;
    private capabilitiesService;
    private allActionComponents;
    private workflowActionClass;
    private customActionClass;
    private simpleWorkflowActionClass;
    private actionsShowingSource;
    actionsShowing$: Observable<ActionShowCommand>;
    constructor(actions: any[], custom_actions: any[], _componentFactoryResolver: ComponentFactoryResolver, bpmService: BpmService, router: Router, capabilitiesService: CapabilitiesService);
    getActionsList(selection: any[], viewContainerRef: ViewContainerRef): Observable<ActionListEntry[]>;
    getMoreActions(selection: any[], viewContainerRef?: any): Observable<ActionListEntry[]>;
    collectProcessActions(selection: any[], viewContainerRef: any): Observable<ActionListEntry[]>;
    collectCustomActions(selection: any[], viewContainerRef: any): Observable<ActionListEntry[]>;
    private getExecutableActionListEntry(actionComponentEntry, action, selection, viewContainerRef);
    getExecutableActionsListFromGivenActions(allActionComponents: any[], selection: any[], viewContainerRef: ViewContainerRef): Observable<ActionListEntry[]>;
    /**
     * Checks if the action is allowed for single ot multiple selection
     * @param action
     * @param itemsCount
     * @returns
     */
    private isRangeAllowed(action, itemsCount);
    /**
     * Show global actions panel
     */
    showActions(selection: any[], target?: string): void;
    /**
     * Hide global actions panel
     */
    hideActions(): void;
    isAllowedType(items: DmsObject[], rejectedType?: any[]): boolean;
}
