import { EventEmitter, OnDestroy, OnInit, ElementRef, AfterViewInit, Renderer2, ChangeDetectorRef } from '@angular/core';
import { Router } from '@angular/router';
import { TranslateService } from '@eo-sdk/core';
import { PageTitleService } from '../../../../eo-framework-core/title/page-title.service';
import { ObjectFormComponent } from '../../../object-form/object-form/object-form.component';
import { ObjectFormOptions, FormStatusChangedEvent } from '../../../object-form';
import { AutoComplete } from 'primeng/primeng';
import { NgForm } from '@angular/forms';
import { LocaleDatePipe } from '../../../../eo-framework-core/pipes/locale-date.pipe';
import { AppSearchService } from '../../../../eo-framework-core/search/app-search.service';
import { UserService, StoredQuery, ObjectType, SearchFilter, SearchQuery, SearchState, SearchService, SystemService, Logger, CapabilitiesService, Capabilities, StoredQueriesService, NotificationsService } from '@eo-sdk/core';
export interface IdxSearch {
    type: ObjectType;
    contextFolderType: ObjectType;
    contextModels?: any[];
    contextAggregations?: {};
    contextFormOptions?: ObjectFormOptions;
    formOptions: ObjectFormOptions;
}
export declare class AppSearchComponent implements OnInit, AfterViewInit, OnDestroy {
    private appSearchService;
    private titleService;
    private searchService;
    private systemService;
    private notifications;
    translate: TranslateService;
    private router;
    private renderer;
    private cd;
    private storedQueriesService;
    private capabilityService;
    private userService;
    private logger;
    PARAMS: {
        TYPE: string;
        CREATOR: string;
        CREATED: string;
        MODIFIER: string;
        MODIFIED: string;
        FILESIZE: string;
        FILENAME: string;
        MIMETYPEGROUP: string;
    };
    OPERATOR: {
        EQUAL: string;
        IN: string;
        GREATER_THAN: string;
        GREATER_OR_EQUAL: string;
        LESS_THAN: string;
        LESS_OR_EQUAL: string;
        INTERVAL: string;
        INTERVAL_INCLUDE_BOTH: string;
        INTERVAL_INCLUDE_TO: string;
        INTERVAL_INCLUDE_FROM: string;
        RANGE: string;
    };
    searchInput: AutoComplete;
    expertInput: ElementRef;
    indexdataForm: ObjectFormComponent;
    contextForm: ObjectFormComponent;
    private querySubscription;
    private queryStateSubscription;
    query: SearchQuery;
    queryState: SearchState;
    capabilities: Capabilities;
    isStoredQuery: boolean;
    isOwnQuery: boolean;
    objectTypeGroups: any[];
    typeGroupTree: any[];
    autocompleteResults: string[];
    idxSearch: IdxSearch;
    expertModeQueryEmpty: boolean;
    expertModeSupport: {
        baseParams: any[];
        selectedGroup: any;
        selectedType: any;
    };
    filtersModel: {};
    aggregationsModel: {};
    datePipe: LocaleDatePipe;
    onExecuteSearch: EventEmitter<{}>;
    readonly storedQuery: StoredQuery;
    constructor(appSearchService: AppSearchService, titleService: PageTitleService, searchService: SearchService, systemService: SystemService, notifications: NotificationsService, translate: TranslateService, router: Router, renderer: Renderer2, cd: ChangeDetectorRef, storedQueriesService: StoredQueriesService, capabilityService: CapabilitiesService, userService: UserService, logger: Logger);
    processFilters(k: string): void;
    syncAggregations(name: any, operator: any): void;
    renderFilter(filter: any, value: any): any;
    resolveLabel(model: any, value: any[]): void;
    resolveSelection(aggs: any[], key: string, selected: boolean): any[];
    resetExpertModeInput(): void;
    toggleExpertMode(): void;
    xpSelectGroup(group: any): void;
    xpSelectType(type: any): void;
    xpAddToTerm(str: any): void;
    toggleType(_type: ObjectType): void;
    isTypeActive(_type: ObjectType): boolean;
    isTypeSaved(_type: ObjectType): boolean;
    getAggregationCount(_type: ObjectType): any;
    private buildFilter(filterType, operator, key);
    setFilter(filterType: string, operator: string, key: any, form?: NgForm): void;
    toggleFilter(filterType: string, operator: string, key: any, selected: boolean): void;
    isEmpty(value: any): any;
    isFilterActive(filterType: string, operator: string, key: any): boolean;
    resetFilter(model: any, value: string): void;
    autocompleteSuggest(evt?: any): void;
    expertTermChanged(): void;
    autocompleteSelect(): void;
    executeSearch(): void;
    private triggerSearch();
    removeTerm(): void;
    removeType(type: ObjectType): void;
    removeContextType(): void;
    removeFilter(filter: SearchFilter): void;
    /**
     * Sets up indexdata search for a given object type
     * @param type - an object type
     * @param contextFolderType - context folder type
     */
    indexdataSearch(type: ObjectType, contextFolderType?: ObjectType): void;
    exitIndexdataSearch(): void;
    setContext(contextFolderName: string): void;
    /**
     * Selects a context type for the current search
     * @param ctx The context form model
     */
    private selectContext(ctx);
    onIndexDataChanged(event: FormStatusChangedEvent): void;
    private updateSearchFilterFromFormData();
    /**
     * Gets the object type element for a filter, to be able to show the
     * label for a filter in the search summary.
     *
     * @param filter - the filter to fetch object type element for
     */
    getObjectTypeElementLabel(filter: SearchFilter): any;
    saveQuery(): void;
    updateStoredQuery(): void;
    resetQuery(): void;
    closeSearchMenu(evt?: any): void;
    private focusSearchInput();
    private changeSearchInputFocus();
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
}
