import { EventEmitter, OnInit, QueryList, AfterViewInit } from '@angular/core';
import { Router } from '@angular/router';
import { TranslateService } from '@eo-sdk/core';
import { Subscription } from 'rxjs';
import { FormStatusChangedEvent } from '../object-form/form-status-changed-event.interface';
import { ObjectFormComponent } from '../object-form/object-form/object-form.component';
import { ObjectFormOptions } from '../object-form/object-form-options.interface';
import { IndexData } from '../ui/indexdata-summary/indexdata-summary.component';
import { SelectionConfig, SelectionService } from '../../eo-framework-core/selection/selection.service';
import { UnsubscribeOnDestroy } from '../util/unsubscribe/unsubscribe.component';
import { DmsParams, ClipboardService, Clipboard, UserService, WorkItemHistoryEntry, InboxService, NotificationsService, BpmService, InboxItem, FileEntry, WorkItem, WorkItemAction, ProcessService, EventService } from '@eo-sdk/core';
import { EmptyState } from '../../eo-framework-core/empty-state/empty-state.interface';
import { TabPluginComponent } from '../plugins/plugin.component';
import { TabPanelComponent } from '../tab-container/tab-panel/tab-panel.component';
export declare class InboxDetailsComponent extends UnsubscribeOnDestroy implements OnInit, AfterViewInit {
    private bpmService;
    private userService;
    private inboxService;
    private selection;
    private router;
    private eventService;
    private clipboardService;
    private processService;
    private translate;
    private notify;
    bpmFormEl: ObjectFormComponent;
    private _item;
    workItem: WorkItem;
    history: WorkItemHistoryEntry[];
    locked: boolean;
    clipboard: Clipboard;
    settings: {
        description: string;
        actionTitle: string;
    };
    formState: FormStatusChangedEvent;
    formOptions: ObjectFormOptions;
    selectedContentFileId: string;
    workItemIndexdata: IndexData;
    performerShow: boolean;
    substituteShow: boolean;
    actionProcessing: Subscription | any;
    initializing: Subscription | any;
    filesAdding: Subscription | any;
    loadError: boolean;
    externalPanels: QueryList<TabPanelComponent>;
    tabPanels: QueryList<TabPanelComponent>;
    tabPlugins: QueryList<TabPluginComponent>;
    emptyState: EmptyState;
    applySelection: SelectionConfig;
    item: InboxItem;
    onDmsItemSelected: EventEmitter<DmsParams>;
    constructor(bpmService: BpmService, userService: UserService, inboxService: InboxService, selection: SelectionService, router: Router, eventService: EventService, clipboardService: ClipboardService, processService: ProcessService, translate: TranslateService, notify: NotificationsService);
    onFormStatusChanged(evt: FormStatusChangedEvent): void;
    /**
     * Process the current inbox item
     */
    private process();
    createDMSItem(dmsType: any): void;
    createBPMWorkItem(): Subscription;
    private setFormOptions(form, data, actions);
    private updateInboxSate();
    private transformActions(actions);
    lockWorkItem(): void;
    /**
     * Un-Locks a work item (de-personalize)
     */
    unlockWorkItem(): void;
    /**
     * Executes a work items action.
     * @param action The action to be executes
     */
    executeWorkItemAction(action: WorkItemAction): void;
    /**
     * Selects a work items file entry an emits onDmsItemSelected event.
     * @param file FileEntry element to be selected
     */
    openWorkItemContent(file?: FileEntry): void;
    /**
     * Opens the file (attached DMSObject) in object state
     * @param file
     */
    openWorkItemContentInContext(evt: any): void;
    /**
     * Adds clipboard content to the work item
     */
    addFromClipboard(): void;
    /**
     * Remove a file entry from the work items file
     * @param file The file entry to be removed
     * @param evt The click event
     */
    removeWorkItemContent(evt: any): void;
    /**
     * Save the work items form data
     */
    saveWorkItemData(): void;
    prepareNewWorkItem(workItem: WorkItem): boolean;
    /**
     * Saves the current work item
     */
    private saveWorkItem();
    /**
     * Removes the current item from the inbox.
     */
    confirmInboxItem(): void;
    /**
     * Sets up state and data for the current work item.
     */
    private setupWorkItem();
    trackByCode(index: any, item: any): any;
    trackById(index: any, item: any): any;
    trackByIndex(index: any, item: any): any;
    ngOnInit(): void;
    ngAfterViewInit(): void;
}
