import { ValidatorFn } from '@angular/forms';
import { ObjectFormControlWrapper } from './object-form/object-form-control-wrapper';
import { ObjectFormGroup } from './object-form/object-form-group';
import { Logger, SystemService } from '@eo-sdk/core';
export declare class ObjectFormHelperService {
    private logger;
    private systemService;
    constructor(logger: Logger, systemService: SystemService);
    /**
     * Converts a form element object to an ObjectFormControlWrapper which then can be used to
     * render a from control. Result can be used as input for FormElementComponent.
     *
     * @param element - the element object or a json string
     * @param situation - optional property to set up a form situation for the control (default is EDIT)
     * @return the converted ObjectFormControlWrapper or null in case of an error
     */
    elementToFormControl(element: any, situation?: string): ObjectFormControlWrapper;
    /**
     * Extract data from an object form based on situation.
     *
     * @param form - form to extract data from
     * @param situation - form situation
     * @param [initialData] - optional form data to match the current values against
     * This is required for editig indexdata (EDIT situation), because we have to compare new values
     * against the initial values. If a property that is contained in the forms initial data is removed
     * (e.g. set to null) then we have to set this null value, because otherwise the server would
     * ignore the changes.
     * @param isTableRowEditForm Flag indicating that the provided form is an inline form used by
     * a forms table element for editing rows. Those need a special handling.
     * @return extracted data as object
     */
    extractFormData(form: ObjectFormGroup, situation: string, initialData?: any, isTableRowEditForm?: boolean): {};
    private getElementValues(data, formControl, situation, initialData?, isTableRowEditForm?);
    private setDataValue(key, value, data, formElement, isTableRowEditForm);
    /**
     * Build validators for the given form element to be attached to
     * a reactive formControl.
     *
     * @param formElement - form element object
     * @param situation - form situation to fetch validators for
     */
    getValidators(formElement: any, situation: string, skipValidation?: boolean): ValidatorFn[];
}
