import { ObjectFormScriptingScope } from './object-form-scripting-scope';
import { Logger, BackendService } from '@eo-sdk/core';
export declare class ObjectFormScriptService {
    private logger;
    private backend;
    constructor(logger: Logger, backend: BackendService);
    /**
     * Run a form script.
     * @param scope - the current scripting scope
     * @param script - the script to be executed
     * @param [scriptName] - the scripts name
     */
    runFormScript(scope: ObjectFormScriptingScope, script: any, scriptName?: string): void;
    /**
     * Define form script function, appending source url as comment.
     * Enables debugging using browser debugging tools (Chrome+Firefox)
     * @see: https://developer.mozilla.org/en-US/docs/Tools/Debugger/How_to/Debug_eval_sources
     *
     * @param name - the name of the script
     * @param script - script to be wrapped in a function
     * @returns the function
     */
    private defineFunction(name, script);
    /**
     * If the script contains global script, this function will import and run them
     * before running the actual script.
     *
     * @param scope - the current scripting scope
     * @param formScriptReturn - the return value of the actual form script
     */
    private importGlobalScriptsAndCallInit(scope, formScriptReturn);
    /**
     * Fetch global scripts.
     * @param name - the name of the global script
     * @param scope - the current scripting scope
     * @returns
     */
    private resolveGlobalScript(name, scope);
}
