export declare class ObjectFormScriptingScope {
    situation: string;
    private onScriptingModelChange;
    api: any;
    private isTableRowScope;
    model: any;
    data: any;
    actions: any;
    objects: any[];
    /**
     * Constructor
     * @param situation - Current form model situation (could be CREATE, SEARCH or EDIT)
     * @param onScriptingModelChange - callback function to be called when the scripting model changed
     * Be aware to provide an instance method as callback for the scripting scope.
     * @see: https://blog.johnnyreilly.com/2014/04/typescript-instance-methods.html
     *
     * @param api - Plugin API reference
     * @param isTableRowScope - set this to true if the current scripting scope is created for a
     * row editing form from a table element. It will then provide the right parameters for the scripting functions
     */
    constructor(situation: string, onScriptingModelChange: any, api: any, isTableRowScope?: boolean);
    /**
     * Sets the internal model and wraps every model element with an observer to be
     * able to track their changes from within a form script
     * @param model
     */
    setModel(model: any): void;
    /**
     * Returns the observed model. Used for row editing forms of table elements that
     * create their own scripting scope in context of their parent form.
     * @returns the observed scripting scope model
     */
    getModel(): any;
    /**
     * Called by the object form when the form model changes.
     * @param change - object with key equals name of the element
     * that changes and value of the new value
     */
    modelChanged(change: any): void;
    /**
     * Runs an elements `onchange` method if available
     *
     * @param modelElement The element itself
     * @param flatValue A flattened version of the elements value (required for table values)
     */
    private runOnChange(modelElement, flatValue?);
}
