import { EventEmitter, OnDestroy, OnInit, ElementRef, AfterViewInit, ChangeDetectorRef } from '@angular/core';
import { ObjectFormScriptService } from './object-form-script/object-form-script.service';
import { ObjectFormHelperService } from '../object-form-helper.service';
import { ObjectFormOptions } from '../object-form-options.interface';
import { FormStatusChangedEvent } from '../form-status-changed-event.interface';
import { UnsubscribeOnDestroy } from '../../util/unsubscribe/unsubscribe.component';
import { PluginsService } from '../../../eo-framework-core/api/plugins.service';
import { Logger, SystemService } from '@eo-sdk/core';
export declare class ObjectFormComponent extends UnsubscribeOnDestroy implements OnDestroy, OnInit, AfterViewInit {
    private logger;
    private elementRef;
    private systemService;
    private formScriptService;
    private formHelperService;
    private pluginService;
    private cdRef;
    isInnerTableForm: boolean;
    statusChanged: EventEmitter<FormStatusChangedEvent>;
    onFormReady: EventEmitter<{}>;
    gCount: number;
    formOptions: ObjectFormOptions;
    form: any;
    private formData;
    private scriptModel;
    private scriptingScope;
    private subscriptions;
    private formControls;
    options: ObjectFormOptions;
    constructor(logger: Logger, elementRef: ElementRef, systemService: SystemService, formScriptService: ObjectFormScriptService, formHelperService: ObjectFormHelperService, pluginService: PluginsService, cdRef: ChangeDetectorRef);
    private init();
    focusForm(): void;
    setFormData(data: any): void;
    /**
     * Extracts the values from the form model. Each form value is represented by one
     * property on the result object holding the fields value. The keys (properties) are the `name`
     * properties of the form element (in SEARCH situation the `qname` field is used).
     *
     * How values are extracted is influenced by the forms situation.
     *
     * @return object of key value pairs
     */
    getFormData(): {};
    setFormPristine(): void;
    resetForm(): void;
    /**
     * Returns the observed model that was passed to the current form script running. If there is
     * no form script, this method will return NULL.
     * @returns
     */
    getObservedScriptModel(): any;
    private buildReactiveForm(formModel);
    private emitFormChangedEvent();
    /**
     * This method will be called each time the script changes its internal model.
     * It is used to transfer the script changes to the actual form model.
     *
     * To ensure the right context, we define an instance method as callback for the scripting scope
     * @see: https://blog.johnnyreilly.com/2014/04/typescript-instance-methods.html
     *
     * @param formControlName
     * @param change
     */
    private onScriptingModelChanged;
    private getDataMeta(formElement, newValue);
    /**
     * Recursive method adding a new FormControl (group or control) to a parent form group
     *
     * @param parentGroup - the parent group to add the control to
     * @param formElement - the enaio form model element to create the child control from
     * @param [useName] - use this name instead of the one from the model
     */
    private addFormControl(parentGroup, formElement, useName?);
    /**
     * Build validators for the given form element to be attached to
     * a reactive formControl.
     *
     * @param formElement - form element object
     */
    private getValidators(formElement);
    /**
     * Extract the values from the form
     */
    private formToData();
    /**
     * Merge data into a form model.
     *
     * @param model - form model
     * @param data - data object or array of SearchFilter objects in case of a search form
     */
    private dataToForm(model, data);
    private setElementValues(elements, data);
    private fetchMetaData(data, element);
    private hasValue(data, element);
    private getValue(data, element);
    private searchFilterToValue(searchFilter);
    private searchFilterToRangeValue(searchFilter);
    ngOnDestroy(): void;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    private unsubscribeAll();
}
