import { OnInit, EventEmitter, ElementRef } from '@angular/core';
import { TranslateService } from '@eo-sdk/core';
import { Router } from '@angular/router';
import { FormStatusChangedEvent } from '../object-form/form-status-changed-event.interface';
import { ObjectFormComponent } from '../object-form/object-form/object-form.component';
import { SelectionConfig, SelectionService } from '../../eo-framework-core/selection/selection.service';
import { UnsubscribeOnDestroy } from '../util/unsubscribe/unsubscribe.component';
import { PendingChangesService } from '../../eo-framework-core/pending-changes/pending-changes.service';
import { PreparedItem, PreparedItemTemplate, PreparedItemType, PrepareService, Logger, SystemService } from '@eo-sdk/core';
import { ObjectFormOptions } from '../object-form';
import { ColDef, GridOptions } from 'ag-grid';
export interface PreparePhase {
    name: string;
    data: any;
}
export declare class PrepareDetailsComponent extends UnsubscribeOnDestroy implements OnInit {
    private prepareService;
    private router;
    private pendingChanges;
    private translate;
    private systemService;
    private selection;
    private logger;
    gridOptions: GridOptions;
    private pendingTaskId;
    file: ElementRef;
    objectForm: ObjectFormComponent;
    PHASE_TYPE: string;
    PHASE_CONTENT: string;
    PHASE_INDEXDATA: string;
    _preparedItem: PreparedItem;
    preparedItem: PreparedItem;
    emptyState: {
        icon: string;
        text: string;
        className: string;
    };
    preparePhase: PreparePhase;
    selectedTemplate: any;
    formOptions: ObjectFormOptions;
    formState: FormStatusChangedEvent;
    templatePreview: string;
    chooseTemplate: boolean;
    uploadInProgress: boolean;
    committing: boolean;
    loading: boolean;
    tagFilterOptions: any;
    header: {
        title: any;
        location: {
            label: any;
            link: any;
        };
        subtitle: any;
    };
    colDefs: ColDef[];
    applySelection: SelectionConfig;
    onItemChanged: EventEmitter<PreparedItem>;
    onCommit: EventEmitter<string>;
    onItemRemove: EventEmitter<PreparedItem>;
    constructor(prepareService: PrepareService, router: Router, pendingChanges: PendingChangesService, translate: TranslateService, systemService: SystemService, selection: SelectionService, logger: Logger);
    cellRenderer(params: any): string;
    private startPending();
    private finishPending();
    /**
     * Commits a prepared item. This will cause the temporary prepared object to be converted to a real DMS-Object.
     * @param openLocationAfterCommit - when set to true, application will navigate to the objects location
     */
    commit(openLocationAfterCommit?: boolean): void;
    removeItem(item: PreparedItem): void;
    getFileNames(item: PreparedItem): string;
    goTo(uri: string): void;
    /**
     * Select a target object type for the current prepared item.
     * @param type - the object types name to be set as target
     */
    selectObjectType(type: PreparedItemType): void;
    /**
     * Add a template to the current prepared item.
     * @param template - the template to be added
     */
    addTemplate(template: PreparedItemTemplate): void;
    /**
     * Select a template. Will show preview for the selected template.
     * @param template - the template to be selected
     */
    selectTemplate(template: PreparedItemTemplate): void;
    setPreviewUri(index: number): void;
    noFile(): void;
    upload(): void;
    fileChangeListener(event: any): void;
    onFormStatusChanged(evt: any): void;
    private process();
    /**
     * Determine the prepare phase to be initialized based on the conditions
     * of the current prepared item.
     */
    private getPreparePhase();
    private createTemplate(selectedTypeObject);
    createTagFilterOptions(templates: PreparedItemTemplate[]): any[];
    /**
     * Initialize a specific prepare phase.
     * @param phase - phase to init (PHASE_TYPE, PHASE_CONTENT, PHASE_INDEXDATA)
     */
    private initPreparePhase(phase);
    private getPreviewData();
    /**
     * Setup title for the current prepared item based on the
     * current prepare phase. Should be called after prepare phase is identified.
     */
    private setupTitle();
    showTemplateSelector(show: boolean): void;
    trackByIdFn(index: any, item: any): any;
    trackByIndexFn(index: any, item: any): any;
    ngOnInit(): void;
}
