import { AfterViewInit, ElementRef, EventEmitter, OnDestroy } from '@angular/core';
import { Router } from '@angular/router';
import { FormGroup, FormBuilder } from '@angular/forms';
import { QuickSearchResult } from './quick-search-result.interface';
import { SearchQuery, SearchState, SearchService, SystemService, ObjectType } from '@eo-sdk/core';
import { AppSearchService } from '../../../eo-framework-core/search/app-search.service';
/**
 * QuickSearchComponent displays a search box that the user can type his query to.
 * It returns a list of matching object types grouped by their object type group and the
 * number of hits for each type. Furthermore it'll provide you with the total number of
 * hits matching the users query.
 *
 * Setting the components `showResults` flag to true, will make the component render the
 * results on its own. If you do want to process results by yourself use the `onResult` callback.
 */
export declare class QuickSearchComponent implements AfterViewInit, OnDestroy {
    private searchService;
    private router;
    private elementRef;
    private appSearchService;
    private systemService;
    private fb;
    private querySubscription;
    queryState: SearchState;
    autocompleteResults: string[];
    query: SearchQuery;
    resultGroups: any;
    resultTypes: any[];
    selected: {
        index: number;
        name: any;
    };
    searchForm: FormGroup;
    invalidTerm: boolean;
    resultsAvailable: any;
    showResults: boolean;
    onResult: EventEmitter<QuickSearchResult>;
    onInputChange: EventEmitter<string>;
    constructor(searchService: SearchService, router: Router, elementRef: ElementRef, appSearchService: AppSearchService, systemService: SystemService, fb: FormBuilder);
    private aggregate();
    onKey(event: any): void;
    executeSearch(objectType?: ObjectType): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
}
