import { EventEmitter, ElementRef, OnInit } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
export interface TreeNode {
    id: string;
    name: string;
    children: TreeNode[];
    path?: string[];
    expanded: boolean;
    selectable: boolean;
    selected: boolean;
    highlighted?: boolean;
    focused?: boolean;
    /** badge to be added to a tree node */
    badges?: TreeNodeBadge[];
    data?: any;
}
export interface TreeNodeBadge {
    value: string;
    cssClass?: string;
}
export interface TreeOptions {
    /** indicating whether or not the user can select just one or multiple values from the tree */
    multiselect?: boolean;
    disableDeselection?: boolean;
}
export declare class TreeComponent implements ControlValueAccessor, OnInit {
    elementRef: ElementRef;
    _tabIndex: number;
    private _expandedNodes;
    private _highlightedNodes;
    private selectedNodes;
    private visibleNodes;
    private focusedNode;
    tree: TreeNode[];
    options: TreeOptions;
    isDisplayed: boolean;
    readonly: boolean;
    expandedNodesChanged: EventEmitter<{}>;
    propagateChange: (_: any) => void;
    constructor(elementRef: ElementRef);
    ngOnInit(): void;
    highlightedNodes: string[];
    treeInput: TreeNode[];
    treeUpdate: TreeNode[];
    onFocusIn(target: any): void;
    onFocusOut(): void;
    onFocus(evt: any): void;
    onBlur(evt: any): void;
    onToggle(evt: any): void;
    onKey(event: KeyboardEvent): void;
    writeValue(selectedNodes: TreeNode[]): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    onNodeSelected(node: any): void;
    onNodeExpanded(node: TreeNode): void;
    toggleExpanded(node: TreeNode): void;
    private updateTree(tree?);
    private updateTreeNode(node, parents);
    private collectVisibleNodes(node?);
    private collectVisibleChildren(nodes?);
    private updateFocus(node?, old?);
    private focusNode(next?);
}
export declare class TreeNodeComponent {
    node: TreeNode;
    onNodeSelected: EventEmitter<{}>;
    onNodeExpandedChanged: EventEmitter<{}>;
    constructor();
    trackById(index: any, item: any): any;
}
