import { ElementRef, Renderer2 } from '@angular/core';
import { Logger, ObjectType, BackendService } from '@eo-sdk/core';
/**
 * Component to display an icon.
 *
 * Specify `iconSrc` attribute to set the src of the icon to be displayed:
 *   <eo-icon [iconSrc]="'assets/svg/ic_favorite.svg'"></eo-icon>
 *
 * Adding the `badge` property will show a tiny badge on top of the icon:
 *   <eo-icon [iconSrc]="{{src}}" [badge]="15"></eo-icon>
 *
 * Adding a `button` class to the component, will style the svg icon more like a button:
 *   <eo-icon class="button" [iconSrc]="{{src}}"></eo-icon>
 *
 * By default all svg-icons will be rendered as kind of black on white. If you like them
 * to be placed on a dark background (and colored white) then add the class `white` to the
 * component:
 *   <eo-icon class="white" [iconSrc]="{{src}}"></eo-icon>
 *
 * You may also provide the component with an `objectType` attribute which expects an
 * `ObjectType` as input. This will then display the svg icon of this ObjectType.
 *
 */
export declare class EoIconComponent {
    private backend;
    private elementRef;
    private _renderer;
    private logger;
    objectType: ObjectType;
    iconId: string;
    iconSrc: string;
    badge: string;
    title: string;
    constructor(backend: BackendService, elementRef: ElementRef, _renderer: Renderer2, logger: Logger);
    private render(svg);
    /**
     * Transforms a string to an SVGElement.
     * @param str - the string to be converted
     * @return the SVGElement created from the input or NULL if conversion failed
     */
    private svgElementFromString(str);
}
