import { OnInit, Renderer2, ElementRef, OnDestroy } from '@angular/core';
import { Router } from '@angular/router';
import { EventService, UploadRegistryService, UploadTarget, UploadFileItem, PrepareService } from '@eo-sdk/core';
import { TranslateService } from "@eo-sdk/core";
export declare class UploadOverlayComponent implements OnInit, OnDestroy {
    private router;
    private renderer;
    private prepareService;
    private translate;
    private eventService;
    private uploadRegistry;
    overlayEl: ElementRef;
    queue: UploadFileItem[];
    fileOver: boolean;
    isUploading: boolean;
    hasValidUploadTargets: boolean;
    invalidInput: boolean;
    queueSize: number;
    validUploadTargets: UploadTarget[];
    selectedUploadTarget: UploadTarget;
    private uploadTargets;
    private dragLeaveListener;
    private dropListener;
    private dragOverListener;
    private escKeyListener;
    private dragEnterListener;
    private dragEventCount;
    constructor(router: Router, renderer: Renderer2, prepareService: PrepareService, translate: TranslateService, eventService: EventService, uploadRegistry: UploadRegistryService);
    private init();
    private onDragEnter(e);
    private _getTransfer(event);
    private _preventAndStop(event);
    private onFilesDropped(fileItems);
    /**
     * Filter list of registered upload targets, so only valid targets will be shown.
     */
    private validateUploadTargets();
    private validateUploadTarget(target);
    /**
     * Removes a file from the list of files to be uploaded.
     * @param fileItem - the file item to be removed
     */
    removeFileItem(fileItem: UploadFileItem): void;
    /**
     * Proceed upload with a selected upload target.
     * @param uploadTarget - the target to upload files to
     */
    proceedWithUpload(uploadTarget: UploadTarget): void;
    /**
     * Proceed upload using the selected upload target.
     * @param useBatchUpload - flag indicating whether or not to use batch upload
     */
    proceedWithSelectedTarget(useBatchUpload: boolean): void;
    /**
     * Resets the selected upload target.
     */
    resetSelectedUploadTarget(): void;
    getStateRoute(): string;
    private successfulUpload(target, uploadTarget);
    /**
     * Start the actual upload.
     * @param uploadTarget - target to upload the files to
     * @param useBatchUpload - flag indicating whether or not to use batch upload
     */
    private startUpload(uploadTarget, [...args]);
    private setQueueSize();
    /**
     * Close the upload overlay and release all bound resources.
     */
    close(): void;
    private unbindListeners();
    /**
     * Indicates whether or not the current drag event contains one or more files.
     * @param event - the drag event to be checked
     * @returns true if files are contained, false otherwise
     */
    private dragContainsFiles(event);
    targetTrackByFn(index: any, item: any): any;
    trackByFn(index: any, item: any): any;
    ngOnInit(): void;
    ngOnDestroy(): void;
}
