import { ModuleWithProviders } from '@angular/core';
import { CoreConfig } from './config/core-config.interface';
/**
 * Main module for connecting an app to an enaio backend. To use it just import int in your app module:
 *
 * ```javascript
 * @NgModule({
 *   imports: [
 *     EoCoreModule.forRoot(<config>)
 *   ], ...})
 * ```
 *
 * add the styles to your CLI project by adding `node_modules/@enaio-sdk/core/main.css` to the styles section of your `angular.json` or
 * use `@import '~@eo-sdk/core/main.css';` in the main styles.scss.
 *
 * ## config
 * `EoCoreModule` can be initialized with a custom configuration: If it's not set, defaults apply.
 *
 * ```json
 *  {
 *    main: EnaioConfig | string[],     // main config object or paths to the config files (defaults to: ['assets/config/main.json'])
 *    translations: string[]            // paths to folders where the translations reside (defaults to: ['assets/i18n/'])
 *  }
 * ```
 *
 * `EoCoreModule` re-exports EoSharedModule, so you can use shared modules (for example translations) inside of your app.
 * If you create your own modules that get imported in your app module, you need to import EoSharedModule there on your own.
 * Just add `import {EoSharedModule} from '@eo-sdk/core';` and you are ready to go. Everything else is
 * handled by `EoCoreModule`.
 */
export declare class EoCoreModule {
    static forRoot(config?: CoreConfig): ModuleWithProviders;
    /**
     * @ignore
     */
    constructor(parentModule: EoCoreModule);
}
