import { OrgUser } from './org.model';
/**
 * Representation of a history entry for a dms object
 */
export declare class DmsObjectHistoryEntry {
    /**
     * Version of the dms object at the time the history entry was created
     */
    version: number;
    /**
     * The time the history entry was created
     */
    time: Date;
    /**
     * Entry's title
     */
    title: string;
    /**
     * Entry's description
     */
    description: string;
    /**
     * Custom comment applied to the entry
     */
    comment: string;
    /**
     * Group of the entry
     */
    group: 'PROCESS' | 'MODIFICATION' | 'INFORMATIONAL';
    /**
     * History entry's type
     */
    type: string;
    /**
     * Additional parameters for special (BPM related) types of entries
     */
    parameter?: {
        processId: string;
        processName: string;
        activityId?: string;
        activityName?: string;
        type: string;
    };
    /**
     * If the history entry was created from a users activity (e.g. indexdata changes), this property
     * holds the user that caused the entry
     */
    user: OrgUser;
    /**
     * Creates a new instance
     * @param json The JSON object received from the backend. This will be used to construct the new history entry instance
     */
    constructor(json: any);
}
