import { ObjectType } from './object-type.model';
/**
 * @ignore
 */
export declare class DmsObjectAttachment {
    id: number;
    name: string;
    size: number;
    type: string;
    previewUri: string;
    /**
     * @param json - server sent JSON for a dms object
     */
    constructor(json: any);
}
/**
 * Representation of a dms object.
 */
export declare class DmsObject {
    /**
     * objects ID
     */
    id: string;
    /**
     * objects title
     */
    title: string;
    /**
     * objects description
     */
    description: string;
    /**
     * objects version number
     */
    version: number;
    /**
     * @ignore
     */
    versions: any[];
    /**
     * object type name
     */
    typeName: string;
    /**
     * objects type
     */
    type?: ObjectType;
    /**
     * Flag indicating whether or not this is the active version of the object
     */
    isActiveVersion: boolean;
    /**
     * Flag indicating whether or not has been finalized
     */
    isFinalized: boolean;
    /**
     * Flag indicating whether or not the object has been marked as favorite
     */
    isFavorite: boolean;
    /**
     * @ignore
     * same as isContextFolder because we do not allow other folders than context folders
     */
    isFolder: boolean;
    /**
     * Flag indicating whether or not the object is a context folder
     */
    isContextFolder: boolean;
    /**
     * Information about the objects context folder
     */
    contextFolder: {
        id: string;
        typeName: string;
        type?: ObjectType;
        title: string;
        description: string;
    };
    /**
     * Indexdata of the object
     */
    data: any;
    /**
     * special right/permissions set up for the object
     */
    rights: any;
    /**
     * Information about the objects creation. Includes the date it was created and the user that created the object
     */
    created: any;
    /**
     * Information about the objects last modification. Includes the date it was modified and the user that modified the object
     */
    modified: any;
    /**
     * Flag indicating whether or not the object is locked. Locked objects are not allowed to be changed
     */
    lock: any;
    /**
     * The objects content (file). May be empty as dms objects can be created without contents
     */
    content: any;
    /**
     * The contents filename
     */
    contentFileName: string;
    /**
     * The contents filesize
     */
    contentFileSize: string;
    /**
     * List of subscriptions for the object
     */
    subscriptions: any[];
    /**
     * List of resubmissions for the object
     */
    resubmissions: any[];
    /**
     * @ignore
     */
    additionalvisibility: any[];
    /**
     * Creates a new instance
     * @param json The JSON object received from the backend. This will be used to construct the new dms object instance
     */
    constructor(json: any);
}
