export declare class EoUser {
    /**
     * The users ID
     */
    id: string;
    /**
     * The users name
     */
    name: string;
    /**
     * The users firstname
     */
    firstname: string;
    /**
     * The users lastname
     */
    lastname: string;
    /**
     * The users title (generated from backends title pattern)
     */
    title: string;
    /**
     * The users email address
     */
    email: string;
    /**
     * Flag indicating whether or not the user is present
     */
    present: boolean;
    /**
     * URI to the users avatar image
     */
    imageUri: string;
    /**
     * Custom user settings
     */
    userSettings: any;
    /**
     * @ignore
     */
    schema: any;
    /**
     * List of the users privileges
     */
    privileges: any[];
    /**
     * List of roles the user belongs to
     */
    roles: any[];
    /**
     * List of the users deputies
     */
    deputies: any[];
    /**
     * List of the users substitutes
     */
    substitutesOf: any[];
    /**
     * @ignore
     */ schemaLocale: string;
    /**
     * @ignore
     */
    uiDirection: string;
    /**
     * Creates a new instance
     * @param json The JSON object received from the backend. This will be used to construct the new user instance
     */
    constructor(json: any);
    /**
     * Checks if the user has a certain privilege
     * @param privilege The privilege to be checked
     * @returns True if the user has this particular privilege, false otherwise
     */
    hasPrivilege(privilege: string): boolean;
    /**
     * Checks if the user has a certain role
     * @param role The role to be checked
     * @returns True if the user has this particular role, false otherwise
     */
    hasRole(role: string): boolean;
    /**
     * adds the base path for the users image path.
     * @param base The base path
     */
    setImageBase(base: string): void;
    /**
     * Gets the users configured client locale
     * @returns locale string
     */
    getClientLocale(): string;
    /**
     * Gets the users configured schema locale
     * @returns locale string
     */
    getSchemaLocale(): string;
}
