/**
 * Items emitted by the inbox service
 */
export declare class InboxItem {
    static TYPE_BPM: string;
    static TYPE_RESUBMISSION: string;
    static TYPE_SUBSCRIPTION: string;
    /**
     * Items ID
     */
    id: string;
    /**
     * Items title
     */
    title: string;
    /**
     * Items description
     */
    description: string;
    /**
     * Items type ('BPM', 'RESUBMISSION', 'SUBSCRIPTION')
     */
    type: string;
    /**
     * ID of the object that caused the inbox entry.
     * In case of type SUBSCRIPTION and RESUBMISSION this is the id of the dms object,
     * for type BPM it is a process id
     */
    sourceId: string;
    /**
     * Items icon ID
     */
    iconId: string;
    /**
     * Flag indicating whether or not the entry has been read
     */
    read: boolean;
    /**
     * Flag indicating that the current user got this task in substitute
     */
    isdeputy: boolean;
    /**
     * escalation date/time
     */
    escalation: Date;
    /**
     * The date the item was received
     */
    received: Date;
    target: any;
    /**
     * Creates a new instance
     * @param json The JSON object received from the backend. This will be used to construct the new inbox item instance
     */
    constructor(json: any);
    /**
     * Determines whether or not the inbox item is escalated
     * @returns True when inbox item is escalated, false otherwise
     */
    isEscalated(): boolean;
}
/**
 * @ignore
 */
export interface InboxState {
    unreadmessages: number;
    escalated: boolean;
}
