import { DmsObject } from './dms-object.model';
import { StructureTreeNode } from '../interface/tree-node.interface';
export declare class UploadTarget {
    id: string;
    type: string;
    /**
     * general filing target
     */
    static ROOT: string;
    /**
     * add file(s) to context folder
     */
    static CONTEXT: string;
    /**
     * add file(s) to context folders dynamic structure
     */
    static CONTEXT_TREE: string;
    /**
     * set/replace content file of a dms object
     */
    static OBJECT: string;
    /**
     * custom targets (e.g. for plugin development)
     */
    static CUSTOM: string;
    name: string;
    description: string;
    /**
     * based on the upload targets type this is the dms object to
     * add/replace content file for (type: OBJECT) or the context folder
     * to add the files to (type: CONTEXT)
     */
    referenceObject: DmsObject;
    /**
     * node from the structure service tree that may hold additional
     * data to be provide to the prepare service
     */
    subFolder: StructureTreeNode;
    /**
     * Creates a new instance of UploadTarget
     *
     * @param id Upload targets unique id
     * @param type Upload targets type
     */
    constructor(id: string, type: string);
    /**
     * Return Method if the Upload is Successfull
     *
     * @param target
     * @returns the provided UploadTarget if the Upload was Successfull.
     */
    onUploadSuccess(target: any): any;
    /**
     * Return method if the Upload fails
     *
     * @returns an empty Object if the Upload fails
     */
    onUploadFail(): {};
}
