import { OrgUser } from './org.model';
/**
 * @ignore
 */
export interface WorkItemHistoryPerformer {
    type: string;
    label: string;
}
/**
 * History entry of a work item.
 */
export declare class WorkItemHistoryEntry {
    /**
     * Key for default type
     */
    TYPE_DEFAULT: string;
    /**
     * Key for error type
     */
    TYPE_ERROR: string;
    /**
     * Key for custom type
     */
    TYPE_CUSTOM: string;
    TYPE_DEADLINE_START: string;
    TYPE_DEADLINE_REACHED: string;
    /**
     * Title of the history entry
     */
    title: string;
    /**
     * Short description of the history entry
     */
    description: string;
    /**
     * The date (time) this entry was created
     */
    time: Date;
    /**
     * Index of the history entry (may be used for ordering)
     */
    number: number;
    /**
     * History entries type
     */
    type: string;
    /**
     * User that was responsible for creating this entry (e.g. by executing an action)
     */
    editor: OrgUser;
    /**
     * Collection of performers. Performers are users, groups or roles that received a work item that let to the creation of a history entry.
     * If for example a work item was forwarded, the history entry created for that action will contain the recipients of the forwarded action.
     */
    performer: WorkItemHistoryPerformer[];
    /**
     * Additional data for special kinds of entries like errors, personalization, periods
     */
    data: any;
    /**
     * Creates a new instance
     * @param json The JSON object received from the backend. This will be used to construct the new work item history instance
     */
    constructor(json: any);
}
