import { Observable } from 'rxjs';
import { HttpClient } from '@angular/common/http';
import { AppCacheService } from '../cache/app-cache.service';
import { Config } from '../config/config.service';
import { EoUser } from '../../model/eo-user.model';
import { SystemService } from '../system/system.service';
import { BackendService } from '../backend/backend.service';
import { UserService } from '../user/user.service';
import { Logger } from '../logger/logger';
import { AuthProfile } from './auth-profile.interface';
import { PrepareService } from '../prepare/prepare.service';
import { InboxService } from '../inbox/inbox.service';
import { CapabilitiesService } from '../capabilities/capabilities.service';
import { LocalStorage } from '@ngx-pwa/local-storage';
import { LocalStorageService } from '../storage/local-storage.service';
import { EventService } from '../events/event.service';
import { BpmService } from '../bpm/bpm.service';
/**
 * `AuthService` handles authentication against an enaio backend.
 */
export declare class AuthService {
    private config;
    private appCache;
    private http;
    private bpmService;
    private capabilitiesService;
    private logger;
    private inboxService;
    private prepareService;
    private backend;
    private systemService;
    private userService;
    private eventService;
    protected storage: LocalStorage;
    protected local: LocalStorageService;
    private userProfileUri;
    private authSource;
    /**
     * Observable to subscribe to for getting the state of being authenticated. Will emit true when a user logged in,
     * false when the user logged out or the gateways session timed out.
     */
    authenticated$: Observable<boolean>;
    /**
     * @ignore
     */
    hosts: string[];
    /**
     * @ignore
     */
    profile: AuthProfile;
    /**
     * @ignore
     */
    constructor(config: Config, appCache: AppCacheService, http: HttpClient, bpmService: BpmService, capabilitiesService: CapabilitiesService, logger: Logger, inboxService: InboxService, prepareService: PrepareService, backend: BackendService, systemService: SystemService, userService: UserService, eventService: EventService, storage: LocalStorage, local: LocalStorageService);
    /**
     * Login a user.
     *
     * @example
     * public login(host: string, username: string, password: string): Observable<EoUser> {
     * fd.append('username', username);
     * }
     *
     * @param host The target host
     * @param username The username
     * @param password The password
     * @returns Resolves with the logged in user
     */
    login(host: string, username: string, password: string): Observable<EoUser>;
    /**
     * @ignore
     */
    initUser(host?: string): Observable<EoUser>;
    /**
     *
     * @param gatewayInfo
     * @param string host
     * @returns Observable<EoUser>
     */
    private fetchUser(gatewayInfo, host?);
    /**
     * Logs out the current user.
     * @param gatewayLogout Flag indicating whether or not to perform a gateway logout as well
     */
    logout(gatewayLogout?: boolean): void;
    /**
     * for desktop and mobile devices we provide a list of hosts for the login
     *
     * @param string host
     */
    private addHostConfig(host);
    /**
     * Get the current state of a user being logged in. This is kind of the synchronous version of subscribing to `authenticated$`.
     * @returns True if there is a logged in user, false otherwise
     */
    isLoggedIn(): boolean;
    /**
     *
     * @param user
     * @param boolean sso
     * @returns Observable<EoUser>
     */
    private initApp(user, sso?);
}
