import { Observable } from 'rxjs';
import { LocalStorage } from '@ngx-pwa/local-storage';
/**
 * The apps central caching service. It will provide the app with an easy to use cache that
 * is aware of the platform it is running on. So it abstracts the platform-specific implementations
 * of a cache from the application.
 */
export declare class AppCacheService {
    protected storage: LocalStorage;
    /**
     * Key for storing system definition
     */
    SYSTEM_DEFINITION: string;
    /**
     * Key for storing system definition
     */
    HOSTS: string;
    /**
     * Key for storing location history
     */
    LOCATION_HISTORY: string;
    constructor(storage: LocalStorage);
    /**
     * Writes an item to the storage.
     * @param key The item's key
     * @param value The value to be stored
     * @returns Resolves true if setting the item succeeded, false otherwise
     */
    setItem(key: string, value: any): Observable<boolean>;
    /**
     * Get a stored item by its key.
     * @param key The item's key
     * @returns The item's value if the key exists, null otherwise
     */
    getItem(key: string): Observable<any>;
    /**
     * Removes an item from the storage.
     * @param key The item's key
     * @returns Resolves true if removing the item succeeded, false otherwise
     */
    removeItem(key: string): Observable<boolean>;
    /**
     * Deletes all items from local storage
     * @returns Resolves true if clearing all items succeeded, false otherwise
     */
    clear(): Observable<boolean>;
}
