import { ClipboardAction } from './clipboard-action.enum';
import { Clipboard } from './clipboard.interface';
import { DmsObject } from '../../model/dms-object.model';
import { Observable } from 'rxjs';
import { EventService } from '../events/event.service';
/**
 * Collection of all Clipboard Services
 */
export declare class ClipboardService {
    private eventService;
    private cacheKey;
    private clipboard;
    private clipboardSource;
    clipboard$: Observable<Clipboard>;
    /**
     * @ignore
     */
    constructor(eventService: EventService);
    /**
     * Setter for the Clipboard
     *
     * @param elements The elements that should be set to the clipboard
     * @param action The type of action (COPY, CUT)
     * @param noCache Whether or not to bypass cache
     */
    set(elements: DmsObject[], action: ClipboardAction, noCache?: boolean): void;
    /**
     * Getter for the Clipboard
     *
     * @returns Clipboard
     */
    get(): Clipboard;
    /**
     * Clears the Clipboard by removing all entries from the Clipboard
     */
    clear(): void;
    /**
     * Update LocalStorage with Clipboard
     */
    private updateCache();
    /**
     * Load Cached Clipbord from LocalStorage
     */
    private loadCachedClipboard();
}
