import { Observable } from 'rxjs';
import { BackendService } from '../backend/backend.service';
import { InboxItem, InboxState } from '../../model/inbox-item.model';
/**
 * InboxService handles interaction with the inbox service on the backend side.
 */
export declare class InboxService {
    private backend;
    private inboxState;
    private inboxStateSource;
    inboxState$: Observable<InboxState>;
    private inboxItems;
    private inboxItemsSource;
    inboxItems$: Observable<InboxItem[]>;
    constructor(backend: BackendService);
    /**
     * Fetches inbox items from the backend.
     *
     * @returns Observable of inbox items.
     */
    getItems(): Observable<InboxItem[]>;
    /**
     * Fetches state informations for the users inbox
     *
     * @returns inbox state object
     */
    getState(): InboxState;
    /**
     * Public access to fetch inbox
     */
    refreshInboxState(): void;
    /**
     * Retrieve inbox state
     */
    private fetchInboxState();
    /**
     * Removes an item from the inbox.
     *
     * @param item inbox item to be removed
     * @returns Observable<any>
     */
    removeItem(item: InboxItem): Observable<any>;
    /**
     * Soft update for data in the inbox.
     *
     * @param id
     * @param item
     * @param multi
     */
    updateInboxItems(id?: string, item?: any, multi?: any[]): void;
    /**
     * Marks an inbox item as read.
     *
     * @param item the item to be marked as read
     * @returns Observable<any>
     */
    markAsRead(item: InboxItem): Observable<any>;
}
