import { Observable } from 'rxjs';
import { BackendService } from '../backend/backend.service';
import { ProcessItem } from '../../model/process-item.model';
import { BpmService } from '../bpm/bpm.service';
import { FileEntry, WorkItem } from '../../model/work-item.model';
import { Clipboard } from '../clipboard/clipboard.interface';
/**
 * Collection of Process Services
 */
export declare class ProcessService {
    private backend;
    private bpmService;
    private processState;
    private processStateSource;
    perocessState$: Observable<any>;
    private processItems;
    private processItemsSource;
    processItems$: Observable<ProcessItem>;
    constructor(backend: BackendService, bpmService: BpmService);
    /**
     * Retrieve All Process Items
     *
     * @param number size
     * @returns Observable<ProcessItem[]>
     */
    getItems(size?: number): Observable<ProcessItem[]>;
    /**
     * Retrieve Process History
     *
     * @param id string
     * @returns Observable<any>
     */
    getHistory(id: string): Observable<any>;
    /**
     * Stated the current State
     *
     * @returns string
     */
    getState(): string;
    /**
     * Public access to refreas process State
     */
    refreshProcessState(): void;
    /**
     * Fetches Processes and sets the processState
     */
    fetchProcessState(): void;
    /**
     * Remove a Process Item by Process Id
     *
     * @param ProcessItem item
     * @returns Observable<any>
     */
    removeItem(item: ProcessItem): Observable<any>;
    /**
     * Update a Process Item by Porcess Id
     *
     * @param string id
     * @param item
     * @param any[] multi
     */
    updateProcessItems(id?: string, item?: any, multi?: any[]): void;
    /**
     * Add a WirkItem from Clipboard
     *
     * @param WorkItem workItem
     * @param Clipboard clipboard
     * @returns Observable<WorkItem | any>
     */
    addFromClipboard(workItem: WorkItem, clipboard: Clipboard): Observable<WorkItem | any>;
    /**
     * remove WorkItem from Process by Process Id and WorkItem Id
     *
     * @param WorkItem workItem
     * @param FileEntry fileEntry
     * @returns Observable<any>
     */
    removeFileElement(workItem: WorkItem, fileEntry: FileEntry): Observable<any>;
}
