/**
 * Wrapper for accessing browsers local storage.
 */
export declare class LocalStorageService {
    private storage;
    constructor();
    /**
     * Sets the provided value to the local storage
     *
     * @param key The items key
     * @param value The items value
     */
    setItem(key: string, value: any): boolean | void;
    /**
     * Retrieves a value by key from local storage and parses it
     *
     * @param key The key of the item to be retrieved
     * @return The stored value
     */
    getItem(key: string): any;
    /**
     * Checks if Key is available in Local Storage
     * @param key The items key
     * @return True if a value exists for the given key, false otherwise
     */
    hasItem(key: string): boolean;
    /**
     * Removes a key value from Local Storage by provided Key
     * @param key The items key
     */
    removeItem(key: string): void;
    /**
     * Clears the Local Storage
     */
    clear(): void;
    /**
     * Checks if a Key is defined in local storage
     * @param key The items key
     * @return True if key eyists, false otherwise
     */
    isKeyDefined(key: string): boolean | void;
    /**
     * Checks if the Browser Supports Local Storage
     */
    private isLocalStorageAvailable();
}
