import { Observable } from 'rxjs';
import { UploadTarget } from '../../model/upload-target.model';
import { PrepareService } from '../prepare/prepare.service';
import { ObjectType } from '../../model/object-type.model';
/**
 * Service for registration of upload targets. Any app component can register itself
 * to retrieve files dragged to the client. This way also plugins are able to fetch and
 * process uploaded files.
 */
export declare class UploadRegistryService {
    private prepareService;
    private _targets;
    private targetsSource;
    /**
     * Stream of currently available upload targets
     */
    uploadTargets$: Observable<UploadTarget[]>;
    /**
     * @ignore
     */
    constructor(prepareService: PrepareService);
    /**
     * Registers a new upload target.
     * If there is an existing target with the same ID it will be updated.
     *
     * @param uploadTarget The target to be registered
     */
    register(uploadTarget: UploadTarget): void;
    /**
     * Checks if it is allowed to drop Files in SubFolders
     *
     * @param subFolder
     * @param ObjectType[] locationTypes
     * @returns boolean
     */
    isSubFolderAllowed(subFolder: any, locationTypes: ObjectType[]): boolean;
    /**
     * Removes an upload target from the list of registered targets.
     *
     * @param uploadTargetId ID of the target to be removed
     */
    unregister(uploadTargetId: string): void;
}
