import { Observable } from 'rxjs';
export declare class Utils {
    /**
     * Utility method for adding parameters to a given URI.
     *
     * @param uri The uri string to attach the parameters to
     * @param params The object containing parameters to be appended
     * @returns the given uri extended by the given parameters + remove empty parameters
     */
    static buildUri(uri: string, params: {}): string;
    /**
     * Creates a unique identifier.
     * @returns A Universally Unique Identifier
     */
    static uuid(): string;
    /**
     * Encode a filename safe for sending chars beyond ASCII-7bit using quoted printable encoding.
     *
     * @param filename The file name
     * @returns The quoted printable filename
     */
    static encodeFileName(filename: string): string;
    /**
     *
     * @param boolean s
     * @return string
     */
    private static _p8(s?);
    /**
     * Converts a javascript text to the utf-8 converted variant.
     * See [unicode]{@link http://thlist.onlinehome.de/thomas_homepage/unicode/UTF-8%20Konvertierung%20mittels%20JavaScript.htm} for reference
     *
     * @param rawinput The input string
     * @returns The utf-8 converted string
     */
    private static encodeToUtf8(rawinput);
    /**
     * Encode symbols that are definitely unsafe (i.e. unsafe in any context). The regular expression describes these unsafe symbols.
     *
     * @param rawinput Input string to be encoded
     * @returns The encoded string
     */
    private static encodeToQuotedPrintable(rawinput);
    /**
     * Compares An Array of Object and Sorts them by given key string
     *
     * ## Example:
     *
     * ```ts
     * Utils.compareAndSortValues('count', 'desc');
     * ```
     *
     * @param key by witch the object should be ordered
     * @param string order direction 'asc' or 'desc'
     * @returns (a, b) => (number | number)
     */
    static compareAndSortValues(key: string | number, order?: string): (a: any, b: any) => number;
    /**
     * Sorts An Array of Object by given key
     * See [ng-packagr issues 696]{@link https://github.com/dherges/ng-packagr/issues/696}
     *
     * @param string key
     * @param string order
     * @returns (a: any, b: any) => number
     */
    static sortValues(key?: string, order?: string): (a: any, b: any) => number;
    /**
     * [ng-packagr issues 696]{@link https://github.com/dherges/ng-packagr/issues/696}
     *
     * @param object
     * @param string key
     * @returns string
     */
    static getProperty(object: any, key?: string): string;
    /**
     * Use on Observable.catch or Observable.subscribe to return empty value
     * [ng-packagr issues 696]{@link https://github.com/dherges/ng-packagr/issues/696}
     *
     * @param (error) => any callback
     * @returns (error) => Observable<never>
     */
    static empty(callback?: (error) => any): (error: any) => Observable<never>;
    /**
     * Use on Observable.catch with specific skipNotification function !!!
     * [ng-packagr issues 696]{@link https://github.com/dherges/ng-packagr/issues/696}
     *
     * @param skipNotification
     * @param callback
     * @param name
     * @param message
     */
    static catchSkip(skipNotification?: (error) => any, callback?: (error) => any, name?: string, message?: string): (error: any) => Observable<never>;
    /**
     * Use on Observable.catch !!!
     * [ng-packagr issues]{@link https://github.com/dherges/ng-packagr/issues/696}
     *
     * @param callback
     * @param name
     * @param message
     * @param skipNotification
     * @return (error) => Observable<never>
     */
    static catch(callback?: (error) => any, name?: string, message?: string, skipNotification?: boolean): (error: any) => Observable<never>;
    /**
     * Use on Observable.subscribe !!!
     * [ng-packagr issues]{@link https://github.com/dherges/ng-packagr/issues/696}
     *
     * @param callback
     * @param name
     * @param message
     * @param skipNotification
     * @return (error) => void
     */
    static throw(callback?: (error) => any, name?: string, message?: string, skipNotification?: boolean): (error: any) => never;
    /**
     * Use on Observable.subscribe only if you want to skip notification / toast!!!
     *
     * @param callback
     * @param name
     * @param message
     * @param skipNotification
     * @return (error) => void
     */
    static logError(callback?: (error) => any, name?: string, message?: string, skipNotification?: boolean): (error: any) => never;
    /**
     * Checks if element is visible
     *
     * @param elem
     * @return boolean
     */
    static isVisible(elem: any): boolean;
    static getBaseHref(): string;
    /**
     *
     * Truncate a string (first argument) if it is longer than the given maximum string length (second argument).
     * Return the truncated string with a ... ending ot whats provided.
     *
     * @param string str
     * @param number num
     * @returns
     */
    static truncateString(str: any, num: any, ending?: string): any;
}
